@@ -17,8 +17,12 @@ from pytorch_lightning.metrics.classification import (
     Accuracy,
     Precision,
     Recall,
-    F1,
+    ConfusionMatrix,
+    PrecisionRecallCurve,
+    AveragePrecision,
+    ROC,
     FBeta,
+    F1,
 )
 
 from pytorch_lightning.metrics.regression import (
